# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

import builtins as _builtins, typing as _typing

import grpc as _grpc
from grpc import aio as _grpc_aio

from .synchronizer_connectivity_pb2 import ConnectSynchronizerRequest, ConnectSynchronizerResponse, DisconnectAllSynchronizersRequest, DisconnectAllSynchronizersResponse, DisconnectSynchronizerRequest, DisconnectSynchronizerResponse, GetSynchronizerIdRequest, GetSynchronizerIdResponse, ListConnectedSynchronizersRequest, ListConnectedSynchronizersResponse, ListRegisteredSynchronizersRequest, ListRegisteredSynchronizersResponse, LogoutRequest, LogoutResponse, ModifySynchronizerRequest, ModifySynchronizerResponse, ReconnectSynchronizerRequest, ReconnectSynchronizerResponse, ReconnectSynchronizersRequest, ReconnectSynchronizersResponse, RegisterSynchronizerRequest, RegisterSynchronizerResponse

__all__ = [
    "SynchronizerConnectivityServiceStub",
]


# noinspection PyPep8Naming,DuplicatedCode
class SynchronizerConnectivityServiceStub:
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc.Channel) -> _SynchronizerConnectivityServiceBlockingStub: ...  # type: ignore
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc_aio.Channel) -> _SynchronizerConnectivityServiceAsyncStub: ...  # type: ignore
    def ConnectSynchronizer(self, __1: ConnectSynchronizerRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ConnectSynchronizerResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, ConnectSynchronizerResponse]: ...
    def RegisterSynchronizer(self, __1: RegisterSynchronizerRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> RegisterSynchronizerResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, RegisterSynchronizerResponse]: ...
    def ReconnectSynchronizers(self, __1: ReconnectSynchronizersRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ReconnectSynchronizersResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, ReconnectSynchronizersResponse]: ...
    def ReconnectSynchronizer(self, __1: ReconnectSynchronizerRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ReconnectSynchronizerResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, ReconnectSynchronizerResponse]: ...
    def ModifySynchronizer(self, __1: ModifySynchronizerRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ModifySynchronizerResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, ModifySynchronizerResponse]: ...
    def DisconnectSynchronizer(self, __1: DisconnectSynchronizerRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> DisconnectSynchronizerResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, DisconnectSynchronizerResponse]: ...
    def DisconnectAllSynchronizers(self, __1: DisconnectAllSynchronizersRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> DisconnectAllSynchronizersResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, DisconnectAllSynchronizersResponse]: ...
    def Logout(self, __1: LogoutRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> LogoutResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, LogoutResponse]: ...
    def ListConnectedSynchronizers(self, __1: ListConnectedSynchronizersRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListConnectedSynchronizersResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, ListConnectedSynchronizersResponse]: ...
    def ListRegisteredSynchronizers(self, __1: ListRegisteredSynchronizersRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListRegisteredSynchronizersResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, ListRegisteredSynchronizersResponse]: ...
    def GetSynchronizerId(self, __1: GetSynchronizerIdRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> GetSynchronizerIdResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, GetSynchronizerIdResponse]: ...

# noinspection PyPep8Naming,DuplicatedCode
class _SynchronizerConnectivityServiceBlockingStub(SynchronizerConnectivityServiceStub):
    def ConnectSynchronizer(self, __1: ConnectSynchronizerRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ConnectSynchronizerResponse: ...
    def RegisterSynchronizer(self, __1: RegisterSynchronizerRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> RegisterSynchronizerResponse: ...
    def ReconnectSynchronizers(self, __1: ReconnectSynchronizersRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ReconnectSynchronizersResponse: ...
    def ReconnectSynchronizer(self, __1: ReconnectSynchronizerRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ReconnectSynchronizerResponse: ...
    def ModifySynchronizer(self, __1: ModifySynchronizerRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ModifySynchronizerResponse: ...
    def DisconnectSynchronizer(self, __1: DisconnectSynchronizerRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> DisconnectSynchronizerResponse: ...
    def DisconnectAllSynchronizers(self, __1: DisconnectAllSynchronizersRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> DisconnectAllSynchronizersResponse: ...
    def Logout(self, __1: LogoutRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> LogoutResponse: ...
    def ListConnectedSynchronizers(self, __1: ListConnectedSynchronizersRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListConnectedSynchronizersResponse: ...
    def ListRegisteredSynchronizers(self, __1: ListRegisteredSynchronizersRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListRegisteredSynchronizersResponse: ...
    def GetSynchronizerId(self, __1: GetSynchronizerIdRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> GetSynchronizerIdResponse: ...

# noinspection PyPep8Naming,DuplicatedCode
class _SynchronizerConnectivityServiceAsyncStub(SynchronizerConnectivityServiceStub):
    def ConnectSynchronizer(self, __1: ConnectSynchronizerRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ConnectSynchronizerResponse]: ...  # type: ignore
    def RegisterSynchronizer(self, __1: RegisterSynchronizerRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, RegisterSynchronizerResponse]: ...  # type: ignore
    def ReconnectSynchronizers(self, __1: ReconnectSynchronizersRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ReconnectSynchronizersResponse]: ...  # type: ignore
    def ReconnectSynchronizer(self, __1: ReconnectSynchronizerRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ReconnectSynchronizerResponse]: ...  # type: ignore
    def ModifySynchronizer(self, __1: ModifySynchronizerRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ModifySynchronizerResponse]: ...  # type: ignore
    def DisconnectSynchronizer(self, __1: DisconnectSynchronizerRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, DisconnectSynchronizerResponse]: ...  # type: ignore
    def DisconnectAllSynchronizers(self, __1: DisconnectAllSynchronizersRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, DisconnectAllSynchronizersResponse]: ...  # type: ignore
    def Logout(self, __1: LogoutRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, LogoutResponse]: ...  # type: ignore
    def ListConnectedSynchronizers(self, __1: ListConnectedSynchronizersRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ListConnectedSynchronizersResponse]: ...  # type: ignore
    def ListRegisteredSynchronizers(self, __1: ListRegisteredSynchronizersRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ListRegisteredSynchronizersResponse]: ...  # type: ignore
    def GetSynchronizerId(self, __1: GetSynchronizerIdRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, GetSynchronizerIdResponse]: ...  # type: ignore



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="TraceContext")


@_attrs_define
class TraceContext:
    """
    Attributes:
        traceparent (str | Unset): https://www.w3.org/TR/trace-context/
        tracestate (str | Unset):
    """

    traceparent: str | Unset = UNSET
    tracestate: str | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        traceparent = self.traceparent

        tracestate = self.tracestate

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if traceparent is not UNSET:
            field_dict["traceparent"] = traceparent
        if tracestate is not UNSET:
            field_dict["tracestate"] = tracestate

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        traceparent = d.pop("traceparent", UNSET)

        tracestate = d.pop("tracestate", UNSET)

        trace_context = cls(
            traceparent=traceparent,
            tracestate=tracestate,
        )

        trace_context.additional_properties = d
        return trace_context

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/sequencer/admin/v30/sequencer_bft_pruning_administration_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/digitalasset/canton/sequencer/admin/v30/sequencer_bft_pruning_administration_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ....admin.pruning.v30 import pruning_pb2 as com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n^com/digitalasset/canton/sequencer/admin/v30/sequencer_bft_pruning_administration_service.proto\x12+com.digitalasset.canton.sequencer.admin.v30\x1a\x37\x63om/digitalasset/canton/admin/pruning/v30/pruning.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"w\n\x0f\x42\x66tPruneRequest\x12\x37\n\tretention\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationR\tretention\x12+\n\x12min_blocks_to_keep\x18\x02 \x01(\x05R\x0fminBlocksToKeep\",\n\x10\x42\x66tPruneResponse\x12\x18\n\x07message\x18\x01 \x01(\tR\x07message\"\x19\n\x17\x42\x66tPruningStatusRequest\"\x95\x02\n\x18\x42\x66tPruningStatusResponse\x12,\n\x12latest_block_epoch\x18\x01 \x01(\x03R\x10latestBlockEpoch\x12!\n\x0clatest_block\x18\x02 \x01(\x03R\x0blatestBlock\x12P\n\x16latest_block_timestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x14latestBlockTimestamp\x12*\n\x11lower_bound_epoch\x18\x04 \x01(\x03R\x0flowerBoundEpoch\x12*\n\x11lower_bound_block\x18\x05 \x01(\x03R\x0flowerBoundBlock\"{\n\x15SetBftScheduleRequest\x12\x62\n\x08schedule\x18\x01 \x01(\x0b\x32\x46.com.digitalasset.canton.sequencer.admin.v30.BftOrdererPruningScheduleR\x08schedule\"\xa0\x01\n\x19\x42\x66tOrdererPruningSchedule\x12V\n\x08schedule\x18\x01 \x01(\x0b\x32:.com.digitalasset.canton.admin.pruning.v30.PruningScheduleR\x08schedule\x12+\n\x12min_blocks_to_keep\x18\x02 \x01(\x05R\x0fminBlocksToKeep\"\x18\n\x16SetBftScheduleResponse\"\x17\n\x15GetBftScheduleRequest\"|\n\x16GetBftScheduleResponse\x12\x62\n\x08schedule\x18\x01 \x01(\x0b\x32\x46.com.digitalasset.canton.sequencer.admin.v30.BftOrdererPruningScheduleR\x08schedule\"H\n\x19SetMinBlocksToKeepRequest\x12+\n\x12min_blocks_to_keep\x18\x01 \x01(\x05R\x0fminBlocksToKeep\"\x1c\n\x1aSetMinBlocksToKeepResponse2\x96\r\n(SequencerBftPruningAdministrationService\x12\x9f\x01\n\x10\x42\x66tPruningStatus\x12\x44.com.digitalasset.canton.sequencer.admin.v30.BftPruningStatusRequest\x1a\x45.com.digitalasset.canton.sequencer.admin.v30.BftPruningStatusResponse\x12\x87\x01\n\x08\x42\x66tPrune\x12<.com.digitalasset.canton.sequencer.admin.v30.BftPruneRequest\x1a=.com.digitalasset.canton.sequencer.admin.v30.BftPruneResponse\x12\x8c\x01\n\x0bSetSchedule\x12=.com.digitalasset.canton.admin.pruning.v30.SetScheduleRequest\x1a>.com.digitalasset.canton.admin.pruning.v30.SetScheduleResponse\x12\x99\x01\n\x0eSetBftSchedule\x12\x42.com.digitalasset.canton.sequencer.admin.v30.SetBftScheduleRequest\x1a\x43.com.digitalasset.canton.sequencer.admin.v30.SetBftScheduleResponse\x12\x80\x01\n\x07SetCron\x12\x39.com.digitalasset.canton.admin.pruning.v30.SetCronRequest\x1a:.com.digitalasset.canton.admin.pruning.v30.SetCronResponse\x12\x95\x01\n\x0eSetMaxDuration\x12@.com.digitalasset.canton.admin.pruning.v30.SetMaxDurationRequest\x1a\x41.com.digitalasset.canton.admin.pruning.v30.SetMaxDurationResponse\x12\x8f\x01\n\x0cSetRetention\x12>.com.digitalasset.canton.admin.pruning.v30.SetRetentionRequest\x1a?.com.digitalasset.canton.admin.pruning.v30.SetRetentionResponse\x12\x92\x01\n\rClearSchedule\x12?.com.digitalasset.canton.admin.pruning.v30.ClearScheduleRequest\x1a@.com.digitalasset.canton.admin.pruning.v30.ClearScheduleResponse\x12\x8c\x01\n\x0bGetSchedule\x12=.com.digitalasset.canton.admin.pruning.v30.GetScheduleRequest\x1a>.com.digitalasset.canton.admin.pruning.v30.GetScheduleResponse\x12\x99\x01\n\x0eGetBftSchedule\x12\x42.com.digitalasset.canton.sequencer.admin.v30.GetBftScheduleRequest\x1a\x43.com.digitalasset.canton.sequencer.admin.v30.GetBftScheduleResponse\x12\xa5\x01\n\x12SetMinBlocksToKeep\x12\x46.com.digitalasset.canton.sequencer.admin.v30.SetMinBlocksToKeepRequest\x1aG.com.digitalasset.canton.sequencer.admin.v30.SetMinBlocksToKeepResponseB\\ZZgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/sequencer/admin/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.sequencer.admin.v30.sequencer_bft_pruning_administration_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZZgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/sequencer/admin/v30'
  _globals['_BFTPRUNEREQUEST']._serialized_start=265
  _globals['_BFTPRUNEREQUEST']._serialized_end=384
  _globals['_BFTPRUNERESPONSE']._serialized_start=386
  _globals['_BFTPRUNERESPONSE']._serialized_end=430
  _globals['_BFTPRUNINGSTATUSREQUEST']._serialized_start=432
  _globals['_BFTPRUNINGSTATUSREQUEST']._serialized_end=457
  _globals['_BFTPRUNINGSTATUSRESPONSE']._serialized_start=460
  _globals['_BFTPRUNINGSTATUSRESPONSE']._serialized_end=737
  _globals['_SETBFTSCHEDULEREQUEST']._serialized_start=739
  _globals['_SETBFTSCHEDULEREQUEST']._serialized_end=862
  _globals['_BFTORDERERPRUNINGSCHEDULE']._serialized_start=865
  _globals['_BFTORDERERPRUNINGSCHEDULE']._serialized_end=1025
  _globals['_SETBFTSCHEDULERESPONSE']._serialized_start=1027
  _globals['_SETBFTSCHEDULERESPONSE']._serialized_end=1051
  _globals['_GETBFTSCHEDULEREQUEST']._serialized_start=1053
  _globals['_GETBFTSCHEDULEREQUEST']._serialized_end=1076
  _globals['_GETBFTSCHEDULERESPONSE']._serialized_start=1078
  _globals['_GETBFTSCHEDULERESPONSE']._serialized_end=1202
  _globals['_SETMINBLOCKSTOKEEPREQUEST']._serialized_start=1204
  _globals['_SETMINBLOCKSTOKEEPREQUEST']._serialized_end=1276
  _globals['_SETMINBLOCKSTOKEEPRESPONSE']._serialized_start=1278
  _globals['_SETMINBLOCKSTOKEEPRESPONSE']._serialized_end=1306
  _globals['_SEQUENCERBFTPRUNINGADMINISTRATIONSERVICE']._serialized_start=1309
  _globals['_SEQUENCERBFTPRUNINGADMINISTRATIONSERVICE']._serialized_end=2995
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/sequencer/api/v30/sequencer_authentication_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/digitalasset/canton/sequencer/api/v30/sequencer_authentication_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ....crypto.v30 import crypto_pb2 as com_dot_digitalasset_dot_canton_dot_crypto_dot_v30_dot_crypto__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nPcom/digitalasset/canton/sequencer/api/v30/sequencer_authentication_service.proto\x12)com.digitalasset.canton.sequencer.api.v30\x1a/com/digitalasset/canton/crypto/v30/crypto.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x83\x04\n\x17SequencerAuthentication\x1a\x64\n\x10\x43hallengeRequest\x12\x16\n\x06member\x18\x01 \x01(\tR\x06member\x12\x38\n\x18member_protocol_versions\x18\x02 \x03(\x05R\x16memberProtocolVersions\x1aM\n\x11\x43hallengeResponse\x12\x14\n\x05nonce\x18\x01 \x01(\x0cR\x05nonce\x12\"\n\x0c\x66ingerprints\x18\x02 \x03(\tR\x0c\x66ingerprints\x1a\x90\x01\n\x13\x41uthenticateRequest\x12\x16\n\x06member\x18\x01 \x01(\tR\x06member\x12K\n\tsignature\x18\x02 \x01(\x0b\x32-.com.digitalasset.canton.crypto.v30.SignatureR\tsignature\x12\x14\n\x05nonce\x18\x03 \x01(\x0cR\x05nonce\x1ag\n\x14\x41uthenticateResponse\x12\x14\n\x05token\x18\x01 \x01(\x0cR\x05token\x12\x39\n\nexpires_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\texpiresAt\x1a%\n\rLogoutRequest\x12\x14\n\x05token\x18\x01 \x01(\x0cR\x05token\x1a\x10\n\x0eLogoutResponse2\xd1\x04\n\x1eSequencerAuthenticationService\x12\xb8\x01\n\tChallenge\x12S.com.digitalasset.canton.sequencer.api.v30.SequencerAuthentication.ChallengeRequest\x1aT.com.digitalasset.canton.sequencer.api.v30.SequencerAuthentication.ChallengeResponse\"\x00\x12\xc1\x01\n\x0c\x41uthenticate\x12V.com.digitalasset.canton.sequencer.api.v30.SequencerAuthentication.AuthenticateRequest\x1aW.com.digitalasset.canton.sequencer.api.v30.SequencerAuthentication.AuthenticateResponse\"\x00\x12\xaf\x01\n\x06Logout\x12P.com.digitalasset.canton.sequencer.api.v30.SequencerAuthentication.LogoutRequest\x1aQ.com.digitalasset.canton.sequencer.api.v30.SequencerAuthentication.LogoutResponse\"\x00\x42ZZXgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/sequencer/api/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.sequencer.api.v30.sequencer_authentication_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZXgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/sequencer/api/v30'
  _globals['_SEQUENCERAUTHENTICATION']._serialized_start=210
  _globals['_SEQUENCERAUTHENTICATION']._serialized_end=725
  _globals['_SEQUENCERAUTHENTICATION_CHALLENGEREQUEST']._serialized_start=237
  _globals['_SEQUENCERAUTHENTICATION_CHALLENGEREQUEST']._serialized_end=337
  _globals['_SEQUENCERAUTHENTICATION_CHALLENGERESPONSE']._serialized_start=339
  _globals['_SEQUENCERAUTHENTICATION_CHALLENGERESPONSE']._serialized_end=416
  _globals['_SEQUENCERAUTHENTICATION_AUTHENTICATEREQUEST']._serialized_start=419
  _globals['_SEQUENCERAUTHENTICATION_AUTHENTICATEREQUEST']._serialized_end=563
  _globals['_SEQUENCERAUTHENTICATION_AUTHENTICATERESPONSE']._serialized_start=565
  _globals['_SEQUENCERAUTHENTICATION_AUTHENTICATERESPONSE']._serialized_end=668
  _globals['_SEQUENCERAUTHENTICATION_LOGOUTREQUEST']._serialized_start=670
  _globals['_SEQUENCERAUTHENTICATION_LOGOUTREQUEST']._serialized_end=707
  _globals['_SEQUENCERAUTHENTICATION_LOGOUTRESPONSE']._serialized_start=709
  _globals['_SEQUENCERAUTHENTICATION_LOGOUTRESPONSE']._serialized_end=725
  _globals['_SEQUENCERAUTHENTICATIONSERVICE']._serialized_start=728
  _globals['_SEQUENCERAUTHENTICATIONSERVICE']._serialized_end=1321
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/admin/pruning/v30/pruning.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/digitalasset/canton/admin/pruning/v30/pruning.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7com/digitalasset/canton/admin/pruning/v30/pruning.proto\x12)com.digitalasset.canton.admin.pruning.v30\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"l\n\x12SetScheduleRequest\x12V\n\x08schedule\x18\x01 \x01(\x0b\x32:.com.digitalasset.canton.admin.pruning.v30.PruningScheduleR\x08schedule\"\x15\n\x13SetScheduleResponse\"\x14\n\x12GetScheduleRequest\"m\n\x13GetScheduleResponse\x12V\n\x08schedule\x18\x01 \x01(\x0b\x32:.com.digitalasset.canton.admin.pruning.v30.PruningScheduleR\x08schedule\"\x82\x01\n\x1dSetParticipantScheduleRequest\x12\x61\n\x08schedule\x18\x01 \x01(\x0b\x32\x45.com.digitalasset.canton.admin.pruning.v30.ParticipantPruningScheduleR\x08schedule\" \n\x1eSetParticipantScheduleResponse\"\x1f\n\x1dGetParticipantScheduleRequest\"\x83\x01\n\x1eGetParticipantScheduleResponse\x12\x61\n\x08schedule\x18\x01 \x01(\x0b\x32\x45.com.digitalasset.canton.admin.pruning.v30.ParticipantPruningScheduleR\x08schedule\"\x9c\x01\n\x0fPruningSchedule\x12\x12\n\x04\x63ron\x18\x01 \x01(\tR\x04\x63ron\x12<\n\x0cmax_duration\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationR\x0bmaxDuration\x12\x37\n\tretention\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationR\tretention\"\xa8\x01\n\x1aParticipantPruningSchedule\x12V\n\x08schedule\x18\x01 \x01(\x0b\x32:.com.digitalasset.canton.admin.pruning.v30.PruningScheduleR\x08schedule\x12\x32\n\x15prune_internally_only\x18\x02 \x01(\x08R\x13pruneInternallyOnly\"\x16\n\x14\x43learScheduleRequest\"\x17\n\x15\x43learScheduleResponse\"$\n\x0eSetCronRequest\x12\x12\n\x04\x63ron\x18\x01 \x01(\tR\x04\x63ron\"\x11\n\x0fSetCronResponse\"U\n\x15SetMaxDurationRequest\x12<\n\x0cmax_duration\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationR\x0bmaxDuration\"\x18\n\x16SetMaxDurationResponse\"N\n\x13SetRetentionRequest\x12\x37\n\tretention\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationR\tretention\"\x16\n\x14SetRetentionResponse\"3\n\x1b\x46indPruningTimestampRequest\x12\x14\n\x05index\x18\x01 \x01(\x05R\x05index\"X\n\x1c\x46indPruningTimestampResponse\x12\x38\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\"\x84\x01\n\x1fSetNoWaitCommitmentsFromRequest\x12\x36\n\x17\x63ounter_participant_ids\x18\x01 \x03(\tR\x15\x63ounterParticipantIds\x12)\n\x10synchronizer_ids\x18\x02 \x03(\tR\x0fsynchronizerIds\"\"\n SetNoWaitCommitmentsFromResponse\"\x86\x01\n!ResetNoWaitCommitmentsFromRequest\x12\x36\n\x17\x63ounter_participant_ids\x18\x01 \x03(\tR\x15\x63ounterParticipantIds\x12)\n\x10synchronizer_ids\x18\x02 \x03(\tR\x0fsynchronizerIds\"$\n\"ResetNoWaitCommitmentsFromResponse\":\n\rSynchronizers\x12)\n\x10synchronizer_ids\x18\x01 \x03(\tR\x0fsynchronizerIds\"w\n\x1fGetNoWaitCommitmentsFromRequest\x12)\n\x10synchronizer_ids\x18\x01 \x03(\tR\x0fsynchronizerIds\x12)\n\x10participant_uids\x18\x02 \x03(\tR\x0fparticipantUids\"\x91\x02\n GetNoWaitCommitmentsFromResponse\x12r\n\x14ignored_participants\x18\x01 \x03(\x0b\x32?.com.digitalasset.canton.admin.pruning.v30.WaitCommitmentsSetupR\x13ignoredParticipants\x12y\n\x18not_ignored_participants\x18\x02 \x03(\x0b\x32?.com.digitalasset.canton.admin.pruning.v30.WaitCommitmentsSetupR\x16notIgnoredParticipants\"\xae\x01\n\x14WaitCommitmentsSetup\x12\x36\n\x17\x63ounter_participant_uid\x18\x01 \x01(\tR\x15\x63ounterParticipantUid\x12^\n\rsynchronizers\x18\x02 \x01(\x0b\x32\x38.com.digitalasset.canton.admin.pruning.v30.SynchronizersR\rsynchronizersBZZXgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/pruning/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.admin.pruning.v30.pruning_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZXgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/pruning/v30'
  _globals['_SETSCHEDULEREQUEST']._serialized_start=167
  _globals['_SETSCHEDULEREQUEST']._serialized_end=275
  _globals['_SETSCHEDULERESPONSE']._serialized_start=277
  _globals['_SETSCHEDULERESPONSE']._serialized_end=298
  _globals['_GETSCHEDULEREQUEST']._serialized_start=300
  _globals['_GETSCHEDULEREQUEST']._serialized_end=320
  _globals['_GETSCHEDULERESPONSE']._serialized_start=322
  _globals['_GETSCHEDULERESPONSE']._serialized_end=431
  _globals['_SETPARTICIPANTSCHEDULEREQUEST']._serialized_start=434
  _globals['_SETPARTICIPANTSCHEDULEREQUEST']._serialized_end=564
  _globals['_SETPARTICIPANTSCHEDULERESPONSE']._serialized_start=566
  _globals['_SETPARTICIPANTSCHEDULERESPONSE']._serialized_end=598
  _globals['_GETPARTICIPANTSCHEDULEREQUEST']._serialized_start=600
  _globals['_GETPARTICIPANTSCHEDULEREQUEST']._serialized_end=631
  _globals['_GETPARTICIPANTSCHEDULERESPONSE']._serialized_start=634
  _globals['_GETPARTICIPANTSCHEDULERESPONSE']._serialized_end=765
  _globals['_PRUNINGSCHEDULE']._serialized_start=768
  _globals['_PRUNINGSCHEDULE']._serialized_end=924
  _globals['_PARTICIPANTPRUNINGSCHEDULE']._serialized_start=927
  _globals['_PARTICIPANTPRUNINGSCHEDULE']._serialized_end=1095
  _globals['_CLEARSCHEDULEREQUEST']._serialized_start=1097
  _globals['_CLEARSCHEDULEREQUEST']._serialized_end=1119
  _globals['_CLEARSCHEDULERESPONSE']._serialized_start=1121
  _globals['_CLEARSCHEDULERESPONSE']._serialized_end=1144
  _globals['_SETCRONREQUEST']._serialized_start=1146
  _globals['_SETCRONREQUEST']._serialized_end=1182
  _globals['_SETCRONRESPONSE']._serialized_start=1184
  _globals['_SETCRONRESPONSE']._serialized_end=1201
  _globals['_SETMAXDURATIONREQUEST']._serialized_start=1203
  _globals['_SETMAXDURATIONREQUEST']._serialized_end=1288
  _globals['_SETMAXDURATIONRESPONSE']._serialized_start=1290
  _globals['_SETMAXDURATIONRESPONSE']._serialized_end=1314
  _globals['_SETRETENTIONREQUEST']._serialized_start=1316
  _globals['_SETRETENTIONREQUEST']._serialized_end=1394
  _globals['_SETRETENTIONRESPONSE']._serialized_start=1396
  _globals['_SETRETENTIONRESPONSE']._serialized_end=1418
  _globals['_FINDPRUNINGTIMESTAMPREQUEST']._serialized_start=1420
  _globals['_FINDPRUNINGTIMESTAMPREQUEST']._serialized_end=1471
  _globals['_FINDPRUNINGTIMESTAMPRESPONSE']._serialized_start=1473
  _globals['_FINDPRUNINGTIMESTAMPRESPONSE']._serialized_end=1561
  _globals['_SETNOWAITCOMMITMENTSFROMREQUEST']._serialized_start=1564
  _globals['_SETNOWAITCOMMITMENTSFROMREQUEST']._serialized_end=1696
  _globals['_SETNOWAITCOMMITMENTSFROMRESPONSE']._serialized_start=1698
  _globals['_SETNOWAITCOMMITMENTSFROMRESPONSE']._serialized_end=1732
  _globals['_RESETNOWAITCOMMITMENTSFROMREQUEST']._serialized_start=1735
  _globals['_RESETNOWAITCOMMITMENTSFROMREQUEST']._serialized_end=1869
  _globals['_RESETNOWAITCOMMITMENTSFROMRESPONSE']._serialized_start=1871
  _globals['_RESETNOWAITCOMMITMENTSFROMRESPONSE']._serialized_end=1907
  _globals['_SYNCHRONIZERS']._serialized_start=1909
  _globals['_SYNCHRONIZERS']._serialized_end=1967
  _globals['_GETNOWAITCOMMITMENTSFROMREQUEST']._serialized_start=1969
  _globals['_GETNOWAITCOMMITMENTSFROMREQUEST']._serialized_end=2088
  _globals['_GETNOWAITCOMMITMENTSFROMRESPONSE']._serialized_start=2091
  _globals['_GETNOWAITCOMMITMENTSFROMRESPONSE']._serialized_end=2364
  _globals['_WAITCOMMITMENTSSETUP']._serialized_start=2367
  _globals['_WAITCOMMITMENTSSETUP']._serialized_end=2541
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/sequencer/api/v30/sequencer_channel_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/digitalasset/canton/sequencer/api/v30/sequencer_channel_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ....crypto.v30 import crypto_pb2 as com_dot_digitalasset_dot_canton_dot_crypto_dot_v30_dot_crypto__pb2
from ....v30 import trace_context_pb2 as com_dot_digitalasset_dot_canton_dot_v30_dot_trace__context__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nIcom/digitalasset/canton/sequencer/api/v30/sequencer_channel_service.proto\x12)com.digitalasset.canton.sequencer.api.v30\x1a/com/digitalasset/canton/crypto/v30/crypto.proto\x1a/com/digitalasset/canton/v30/trace_context.proto\"\xf3\x03\n ConnectToSequencerChannelRequest\x12\x61\n\x08metadata\x18\x01 \x01(\x0b\x32\x43.com.digitalasset.canton.sequencer.api.v30.SequencerChannelMetadataH\x00R\x08metadata\x12h\n\x0bsession_key\x18\x02 \x01(\x0b\x32\x45.com.digitalasset.canton.sequencer.api.v30.SequencerChannelSessionKeyH\x00R\nsessionKey\x12\x8a\x01\n\x1bsession_key_acknowledgement\x18\x03 \x01(\x0b\x32H.com.digitalasset.canton.sequencer.api.v30.SequencerChannelSessionKeyAckH\x00R\x19sessionKeyAcknowledgement\x12\x1a\n\x07payload\x18\x04 \x01(\x0cH\x00R\x07payload\x12N\n\rtrace_context\x18\x05 \x01(\x0b\x32).com.digitalasset.canton.v30.TraceContextR\x0ctraceContextB\t\n\x07request\"\x86\x04\n!ConnectToSequencerChannelResponse\x12r\n\tconnected\x18\x01 \x01(\x0b\x32R.com.digitalasset.canton.sequencer.api.v30.SequencerChannelConnectedToAllEndpointsH\x00R\tconnected\x12h\n\x0bsession_key\x18\x02 \x01(\x0b\x32\x45.com.digitalasset.canton.sequencer.api.v30.SequencerChannelSessionKeyH\x00R\nsessionKey\x12\x8a\x01\n\x1bsession_key_acknowledgement\x18\x03 \x01(\x0b\x32H.com.digitalasset.canton.sequencer.api.v30.SequencerChannelSessionKeyAckH\x00R\x19sessionKeyAcknowledgement\x12\x1a\n\x07payload\x18\x04 \x01(\x0cH\x00R\x07payload\x12N\n\rtrace_context\x18\x05 \x01(\x0b\x32).com.digitalasset.canton.v30.TraceContextR\x0ctraceContextB\n\n\x08response\"\r\n\x0bPingRequest\"\x0e\n\x0cPingResponse\"\x91\x01\n\x18SequencerChannelMetadata\x12\x1d\n\nchannel_id\x18\x01 \x01(\tR\tchannelId\x12+\n\x11initiating_member\x18\x02 \x01(\tR\x10initiatingMember\x12)\n\x10receiving_member\x18\x03 \x01(\tR\x0freceivingMember\")\n\'SequencerChannelConnectedToAllEndpoints\"\x89\x01\n\x1aSequencerChannelSessionKey\x12k\n\x15\x65ncrypted_session_key\x18\x01 \x01(\x0b\x32\x37.com.digitalasset.canton.crypto.v30.AsymmetricEncryptedR\x13\x65ncryptedSessionKey\"\x1f\n\x1dSequencerChannelSessionKeyAck2\xcf\x02\n\x17SequencerChannelService\x12\xba\x01\n\x19\x43onnectToSequencerChannel\x12K.com.digitalasset.canton.sequencer.api.v30.ConnectToSequencerChannelRequest\x1aL.com.digitalasset.canton.sequencer.api.v30.ConnectToSequencerChannelResponse(\x01\x30\x01\x12w\n\x04Ping\x12\x36.com.digitalasset.canton.sequencer.api.v30.PingRequest\x1a\x37.com.digitalasset.canton.sequencer.api.v30.PingResponseBZZXgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/sequencer/api/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.sequencer.api.v30.sequencer_channel_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZXgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/sequencer/api/v30'
  _globals['_CONNECTTOSEQUENCERCHANNELREQUEST']._serialized_start=219
  _globals['_CONNECTTOSEQUENCERCHANNELREQUEST']._serialized_end=718
  _globals['_CONNECTTOSEQUENCERCHANNELRESPONSE']._serialized_start=721
  _globals['_CONNECTTOSEQUENCERCHANNELRESPONSE']._serialized_end=1239
  _globals['_PINGREQUEST']._serialized_start=1241
  _globals['_PINGREQUEST']._serialized_end=1254
  _globals['_PINGRESPONSE']._serialized_start=1256
  _globals['_PINGRESPONSE']._serialized_end=1270
  _globals['_SEQUENCERCHANNELMETADATA']._serialized_start=1273
  _globals['_SEQUENCERCHANNELMETADATA']._serialized_end=1418
  _globals['_SEQUENCERCHANNELCONNECTEDTOALLENDPOINTS']._serialized_start=1420
  _globals['_SEQUENCERCHANNELCONNECTEDTOALLENDPOINTS']._serialized_end=1461
  _globals['_SEQUENCERCHANNELSESSIONKEY']._serialized_start=1464
  _globals['_SEQUENCERCHANNELSESSIONKEY']._serialized_end=1601
  _globals['_SEQUENCERCHANNELSESSIONKEYACK']._serialized_start=1603
  _globals['_SEQUENCERCHANNELSESSIONKEYACK']._serialized_end=1634
  _globals['_SEQUENCERCHANNELSERVICE']._serialized_start=1637
  _globals['_SEQUENCERCHANNELSERVICE']._serialized_end=1972
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from . import package_service_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v2_dot_package__service__pb2

GRPC_GENERATED_VERSION = '1.76.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + ' but the generated code in com/daml/ledger/api/v2/package_service_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class PackageServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListPackages = channel.unary_unary(
                '/com.daml.ledger.api.v2.PackageService/ListPackages',
                request_serializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_package__service__pb2.ListPackagesRequest.SerializeToString,
                response_deserializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_package__service__pb2.ListPackagesResponse.FromString,
                _registered_method=True)
        self.GetPackage = channel.unary_unary(
                '/com.daml.ledger.api.v2.PackageService/GetPackage',
                request_serializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_package__service__pb2.GetPackageRequest.SerializeToString,
                response_deserializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_package__service__pb2.GetPackageResponse.FromString,
                _registered_method=True)
        self.GetPackageStatus = channel.unary_unary(
                '/com.daml.ledger.api.v2.PackageService/GetPackageStatus',
                request_serializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_package__service__pb2.GetPackageStatusRequest.SerializeToString,
                response_deserializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_package__service__pb2.GetPackageStatusResponse.FromString,
                _registered_method=True)
        self.ListVettedPackages = channel.unary_unary(
                '/com.daml.ledger.api.v2.PackageService/ListVettedPackages',
                request_serializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_package__service__pb2.ListVettedPackagesRequest.SerializeToString,
                response_deserializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_package__service__pb2.ListVettedPackagesResponse.FromString,
                _registered_method=True)


class PackageServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListPackages(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPackage(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPackageStatus(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListVettedPackages(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_PackageServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListPackages': grpc.unary_unary_rpc_method_handler(
                    servicer.ListPackages,
                    request_deserializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_package__service__pb2.ListPackagesRequest.FromString,
                    response_serializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_package__service__pb2.ListPackagesResponse.SerializeToString,
            ),
            'GetPackage': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPackage,
                    request_deserializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_package__service__pb2.GetPackageRequest.FromString,
                    response_serializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_package__service__pb2.GetPackageResponse.SerializeToString,
            ),
            'GetPackageStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPackageStatus,
                    request_deserializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_package__service__pb2.GetPackageStatusRequest.FromString,
                    response_serializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_package__service__pb2.GetPackageStatusResponse.SerializeToString,
            ),
            'ListVettedPackages': grpc.unary_unary_rpc_method_handler(
                    servicer.ListVettedPackages,
                    request_deserializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_package__service__pb2.ListVettedPackagesRequest.FromString,
                    response_serializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_package__service__pb2.ListVettedPackagesResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'com.daml.ledger.api.v2.PackageService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('com.daml.ledger.api.v2.PackageService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class PackageService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListPackages(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.daml.ledger.api.v2.PackageService/ListPackages',
            com_dot_daml_dot_ledger_dot_api_dot_v2_dot_package__service__pb2.ListPackagesRequest.SerializeToString,
            com_dot_daml_dot_ledger_dot_api_dot_v2_dot_package__service__pb2.ListPackagesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetPackage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.daml.ledger.api.v2.PackageService/GetPackage',
            com_dot_daml_dot_ledger_dot_api_dot_v2_dot_package__service__pb2.GetPackageRequest.SerializeToString,
            com_dot_daml_dot_ledger_dot_api_dot_v2_dot_package__service__pb2.GetPackageResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetPackageStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.daml.ledger.api.v2.PackageService/GetPackageStatus',
            com_dot_daml_dot_ledger_dot_api_dot_v2_dot_package__service__pb2.GetPackageStatusRequest.SerializeToString,
            com_dot_daml_dot_ledger_dot_api_dot_v2_dot_package__service__pb2.GetPackageStatusResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListVettedPackages(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.daml.ledger.api.v2.PackageService/ListVettedPackages',
            com_dot_daml_dot_ledger_dot_api_dot_v2_dot_package__service__pb2.ListVettedPackagesRequest.SerializeToString,
            com_dot_daml_dot_ledger_dot_api_dot_v2_dot_package__service__pb2.ListVettedPackagesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

from .sequencing_parameters_pb2 import DynamicSequencingParameters
from .traffic_control_parameters_pb2 import SetTrafficPurchasedMessage, TrafficConsumed, TrafficControlParameters, TrafficPurchased, TrafficReceipt, TrafficState
from .synchronizer_parameters_pb2 import AcsCommitmentsCatchUpConfig, DynamicSynchronizerParameters, OnboardingRestriction, ParticipantSynchronizerLimits
from .topology_pb2 import DecentralizedNamespaceDefinition, DynamicSequencingParametersState, Enums, MediatorSynchronizerState, MultiTransactionSignatures, NamespaceDelegation, OwnerToKeyMapping, ParticipantSynchronizerPermission, PartyHostingLimits, PartyToKeyMapping, PartyToParticipant, SequencerConnectionSuccessor, SequencerSynchronizerState, SignedTopologyTransaction, SignedTopologyTransactions, SynchronizerParametersState, SynchronizerTrustCertificate, SynchronizerUpgradeAnnouncement, TopologyMapping, TopologyTransaction, TopologyTransactionsBroadcast, VettedPackages
from .common_pb2 import ContractAuthenticationData, ViewType
from .common_stable_pb2 import AggregationRule, GlobalKey, SerializableContract, Stakeholders
from .merkle_pb2 import BlindableNode, GenTransactionTree, MerkleSeq, MerkleSeqElement
from .quorum_pb2 import PartyIndexAndWeight, Quorum
from .participant_transaction_pb2 import ActionDescription, CommonMetadata, CreatedContract, DeduplicationPeriod, EncryptedViewMessage, ExternalAuthorization, ExternalPartyAuthorization, FullInformeeTree, Informee, InformeeMessage, InputContract, LightTransactionViewTree, ParticipantMetadata, RootHashMessage, SubmitterMetadata, ViewCommonData, ViewHashAndKey, ViewNode, ViewParticipantData, ViewParticipantMessage
from .participant_reassignment_pb2 import ActiveContract, AssignmentCommonData, AssignmentMediatorMessage, AssignmentView, ReassignmentId, ReassignmentSubmitterMetadata, ReassignmentViewTree, UnassignmentCommonData, UnassignmentData, UnassignmentMediatorMessage, UnassignmentView
from .confirmation_response_pb2 import ConfirmationResponse, ConfirmationResponses, LocalVerdict, MerkleSeqIndex, ViewPosition
from .mediator_pb2 import ConfirmationResultMessage, InformeeTree, MediatorReject, ParticipantReject, RejectionReason, Verdict
from .versioned_google_rpc_status_pb2 import VersionedStatus
from .sequencing_pb2 import Batch, CompressedBatch, Envelope, PossiblyIgnoredSequencedEvent, Recipients, RecipientsTree, SequencedEvent, SequencingSubmissionCost, ServiceAgreement, StaticSynchronizerParameters, SubmissionRequest
from .storage_pb2 import StoredParties
from .synchronization_pb2 import EnvelopeContent, SignedProtocolMessage, TypedSignedProtocolMessageContent
from .ordering_request_pb2 import OrderingRequest
from .signed_content_pb2 import SignedContent
from .acs_commitments_pb2 import AcsCommitment

__all__ = [
    "AcsCommitment",
    "AcsCommitmentsCatchUpConfig",
    "ActionDescription",
    "ActiveContract",
    "AggregationRule",
    "AssignmentCommonData",
    "AssignmentMediatorMessage",
    "AssignmentView",
    "Batch",
    "BlindableNode",
    "CommonMetadata",
    "CompressedBatch",
    "ConfirmationResponse",
    "ConfirmationResponses",
    "ConfirmationResultMessage",
    "ContractAuthenticationData",
    "CreatedContract",
    "DecentralizedNamespaceDefinition",
    "DeduplicationPeriod",
    "DynamicSequencingParameters",
    "DynamicSequencingParametersState",
    "DynamicSynchronizerParameters",
    "EncryptedViewMessage",
    "Enums",
    "Envelope",
    "EnvelopeContent",
    "ExternalAuthorization",
    "ExternalPartyAuthorization",
    "FullInformeeTree",
    "GenTransactionTree",
    "GlobalKey",
    "Informee",
    "InformeeMessage",
    "InformeeTree",
    "InputContract",
    "LightTransactionViewTree",
    "LocalVerdict",
    "MediatorReject",
    "MediatorSynchronizerState",
    "MerkleSeq",
    "MerkleSeqElement",
    "MerkleSeqIndex",
    "MultiTransactionSignatures",
    "NamespaceDelegation",
    "OnboardingRestriction",
    "OrderingRequest",
    "OwnerToKeyMapping",
    "ParticipantMetadata",
    "ParticipantReject",
    "ParticipantSynchronizerLimits",
    "ParticipantSynchronizerPermission",
    "PartyHostingLimits",
    "PartyIndexAndWeight",
    "PartyToKeyMapping",
    "PartyToParticipant",
    "PossiblyIgnoredSequencedEvent",
    "Quorum",
    "ReassignmentId",
    "ReassignmentSubmitterMetadata",
    "ReassignmentViewTree",
    "Recipients",
    "RecipientsTree",
    "RejectionReason",
    "RootHashMessage",
    "SequencedEvent",
    "SequencerConnectionSuccessor",
    "SequencerSynchronizerState",
    "SequencingSubmissionCost",
    "SerializableContract",
    "ServiceAgreement",
    "SetTrafficPurchasedMessage",
    "SignedContent",
    "SignedProtocolMessage",
    "SignedTopologyTransaction",
    "SignedTopologyTransactions",
    "Stakeholders",
    "StaticSynchronizerParameters",
    "StoredParties",
    "SubmissionRequest",
    "SubmitterMetadata",
    "SynchronizerParametersState",
    "SynchronizerTrustCertificate",
    "SynchronizerUpgradeAnnouncement",
    "TopologyMapping",
    "TopologyTransaction",
    "TopologyTransactionsBroadcast",
    "TrafficConsumed",
    "TrafficControlParameters",
    "TrafficPurchased",
    "TrafficReceipt",
    "TrafficState",
    "TypedSignedProtocolMessageContent",
    "UnassignmentCommonData",
    "UnassignmentData",
    "UnassignmentMediatorMessage",
    "UnassignmentView",
    "Verdict",
    "VersionedStatus",
    "VettedPackages",
    "ViewCommonData",
    "ViewHashAndKey",
    "ViewNode",
    "ViewParticipantData",
    "ViewParticipantMessage",
    "ViewPosition",
    "ViewType",
]



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from ..v2 import topology_pb2 as _topology_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TopologyTransaction(_message.Message):
    __slots__ = ("state_update", "domain_governance")
    STATE_UPDATE_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_GOVERNANCE_FIELD_NUMBER: _ClassVar[int]
    state_update: _topology_pb2.TopologyStateUpdate
    domain_governance: _topology_pb2.DomainGovernanceTransaction
    def __init__(self, state_update: _Optional[_Union[_topology_pb2.TopologyStateUpdate, _Mapping]] = ..., domain_governance: _Optional[_Union[_topology_pb2.DomainGovernanceTransaction, _Mapping]] = ...) -> None: ...



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0

"""
DAML-LF fast lookups
--------------------
"""

from __future__ import annotations

from collections import defaultdict
from dataclasses import dataclass
import threading
from types import MappingProxyType
from typing import (
    AbstractSet,
    Any,
    Collection,
    Generic,
    Iterable,
    Iterator,
    Literal,
    Mapping,
    NoReturn,
    Optional,
    Sequence,
    TypeVar,
    overload,
)
import warnings

from .. import LOG
from .daml_lf_1 import (
    Archive,
    DefDataType,
    DefInterface,
    DefTemplate,
    DefValue,
    DottedName,
    ModuleRef,
    Package,
    PackageRef,
    TemplateChoice,
    TypeConName,
    ValName,
    _Name,
)
from .errors import AmbiguousMatchError, NameNotFoundError, PackageNotFoundError
from .protocols import SymbolLookup, TemplateOrInterface
from .util import package_local_name, package_ref

__all__ = [
    "STAR",
    "LookupResult",
    "EmptyLookup",
    "MultiPackageLookup",
    "PackageLookup",
    "PackageExceptionTracker",
    "SymbolLookup",
    "find_choice",
    "matching_normalizations",
    "normalize",
    "parse_type_con_name",
    "validate_template",
]

K = TypeVar("K", bound=_Name)
V = TypeVar("V")
STAR = PackageRef("*")


def parse_type_con_name(val: str, /) -> TypeConName:
    """
    Parse the given string as a type constructor.
    """
    pkg, name = validate_template(val)
    module_name, _, entity_name = name.rpartition(":")
    if module_name:
        module_ref = ModuleRef(pkg, DottedName(module_name.split(".")))
    else:
        module_ref = ModuleRef(pkg, DottedName())
    return TypeConName(module_ref, entity_name.split("."))


def empty_lookup_impl(ref: Any, /) -> NoReturn:
    pkg, _ = validate_template(ref)
    if pkg != STAR:
        raise PackageNotFoundError(pkg)
    else:
        raise NameNotFoundError(ref)


def validate_template(template: Any, /) -> tuple[PackageRef, str]:
    """
    Return a module and type name component from something that can be interpreted as a template.

    :param template:
        Any object that can be interpreted as an identifier for a template.
    :return:
        A tuple of package ID and ``Module.Name:EntityName`` (the package-scoped identifier for the
        type). The special value ``'*'`` is used if either the package ID, module name, or both
        should be wildcarded.
    :raise ValueError:
        If the object could not be interpreted as a thing referring to a template.
    """
    if template == "*" or template is None:
        return STAR, "*"

    if isinstance(template, str):
        components = template.split(":")
        if len(components) == 3:
            # correct number of colons for a fully-qualified name
            pkgid, m, e = components
            return PackageRef(pkgid), f"{m}:{e}"

        elif len(components) == 2:
            # one colon, so assume the package ID is unspecified UNLESS the second component is a
            # wildcard; then we assume the wildcard means any module name and entity name
            m, e = components
            if m == STAR and e != STAR:
                # strings that look like "*:SOMETHING" are explicitly not allowed unless deprecated
                # identifier support is requested; this is almost certainly an attempt to use
                # periods instead of colons as a delimiter between module name and entity name
                raise ValueError("string must be in the format PKG_REF:MOD:ENTITY or MOD:ENTITY")

            return (STAR, f"{m}:{e}") if e != "*" else (PackageRef(m), "*")

        else:
            raise ValueError("string must be in the format PKG_REF:MOD:ENTITY or MOD:ENTITY")

    if isinstance(template, TypeConName):
        return package_ref(template), package_local_name(template)
    else:
        raise ValueError(f"Don't know how to convert {template!r} into a template")


def normalize(name: Optional[str | TypeConName], /) -> str:
    """
    Return the canonical form for a string that represents a template ID or partial match of a
    template ID.

    Concretely, this function converts ``"MyMod:MyTemplate"`` to ``"*:MyMod:MyTemplate"`` and leaves
    most other strings unchanged.

    :param name:
        A template ID, expressed in either string form or as an instance of :class:`TypeConName`.
    :return:
        A string in canonical form (either ``PACKAGE_REF:MODULE_NAME:ENTITY_NAME`` or
        ``PACKAGE_REF:*``, where ``PACKAGE_REF`` is also allowed to be ``*``).
    """
    p, m = validate_template(name)
    return f"{p}:{m}"


def matching_normalizations(name: str | TypeConName, /) -> Sequence[str]:
    """
    Return strings that are possible matches for the given template ID.
    """
    p, m = validate_template(name)

    # throw away duplicates that arise from `name` not being fully specified (p and/or m are
    # allowed to be asterisks too)
    return list(dict.fromkeys([f"{p}:{m}", f"{p}:*", f"*:{m}", "*:*"]))


class LookupResult:
    """
    The results from a :meth:`SymbolLookup.lookup` call.
    """

    ref: Any
    data_types: LookupMapping[TypeConName, DefDataType]
    values: LookupMapping[ValName, DefValue]
    templates: LookupMapping[TypeConName, DefTemplate]
    interfaces: LookupMapping[TypeConName, DefInterface]

    def __init__(
        self,
        ref: Any,
        /,
        *,
        data_types: Sequence[LookupMappingItem[TypeConName, DefDataType]] = (),
        values: Sequence[LookupMappingItem[ValName, DefValue]] = (),
        templates: Sequence[LookupMappingItem[TypeConName, DefTemplate]] = (),
        interfaces: Sequence[LookupMappingItem[TypeConName, DefInterface]] = (),
    ) -> None:
        self.ref = ref
        self.data_types = LookupMapping(self, data_types)
        self.values = LookupMapping(self, values)
        self.templates = LookupMapping(self, templates)
        self.interfaces = LookupMapping(self, interfaces)

    def __bool__(self) -> bool:
        """
        Return ``True`` if this :class:`LookupResult` contains objects, or ``False`` otherwise.
        """
        return bool(self.data_types or self.values or self.templates or self.interfaces)

    def __add__(self, other: LookupResult, /) -> LookupResult:
        return LookupResult(
            self.ref,
            data_types=[*self.data_types._items, *other.data_types._items],
            values=[*self.values._items, *other.values._items],
            templates=[*self.templates._items, *other.templates._items],
            interfaces=[*self.interfaces._items, *other.interfaces._items],
        )


@dataclass(frozen=True)
class LookupMappingItem(Generic[K, V]):
    package_id_ref: K
    package_name_ref: Optional[K]
    object: V


class LookupMapping(Mapping[K, V]):
    """
    A mapping of references (where the :class:`PackageRef` is either ID-based or package name-based)
    to objects of a certain type.

    THIS IS NOT AN EFFICIENT STRUCTURE.
    """

    def __init__(self, parent: LookupResult, items: Sequence[LookupMappingItem[K, V]], /) -> None:
        """
        Construct a :class:`LookupMapping`.

        :param parent:
            The parent :class:`LookupMapping`.
        :param items:
            An ordered sequence of (ref [by package ID], ref [by package name], value).
            The package name is optional.
        """
        self._parent = parent
        self._items = tuple(items)

    def __getitem__(self, key: K, /) -> V:
        """
        Return the object that matches the specified key. This key can either be package-ID-based
        or package-name based.

        :param key: The key to fetch.
        :return: The matching object.
        :raises KeyError:
            Raised if the specified mapping does not exist.
        """
        for item in self._items:
            if key == item.package_id_ref or key == item.package_name_ref:
                return item.object
        raise KeyError(key)

    def __iter__(self) -> Iterator[K]:
        """
        Return an iterator over the package ID-based keys in this structure.
        """
        for item in self._items:
            yield item.package_id_ref

    def __len__(self) -> int:
        """
        Return the number of objects in this mapping.
        """
        return len(self._items)

    def __add__(self, other: LookupMapping[K, V], /) -> LookupMapping[K, V]:
        """
        Add the contents of this mapping and another mapping; return a new mapping that
        is the combined contents.

        :param other:
        :return:
        """
        return LookupMapping(self._parent, [*self._items, *other._items])

    def single(self) -> LookupMappingItem[K, V]:
        """
        Return the name and matching symbol in this :class:`LookupMapping`.

        When there are multiple matches because of Smart Contract Upgrade-compatible
        names, the most recent version is returned. Otherwise, if there are multiple
        matches, then an :class:`AmbiguousMatchError` is raised. If no names were
        found, a :class:`NameNotFoundError` is instead raised.
        """
        i = iter(self._items)
        item = next(i, None)
        if not item:
            raise NameNotFoundError(self._parent.ref)

        while other := next(i, None):
            # to support Smart Contract Upgradaes, multiple matches are allowed,
            # but only when the package names are the same
            if item.package_name_ref != other.package_name_ref:
                raise AmbiguousMatchError(self._parent.ref)

        return item

    def package_id_refs(self) -> Iterable[K]:
        """
        Return the unique set of package ID-based references that have matched.
        """
        for item in self._items:
            yield item.package_id_ref

    def package_name_refs(self) -> Iterable[K]:
        """
        Return the unique set of package name-based references that have matched.
        """
        seen = set[K]()
        for item in self._items:
            if item.package_name_ref is not None and item.package_name_ref not in seen:
                seen.add(item.package_name_ref)
                yield item.package_name_ref


class EmptyLookup(SymbolLookup):
    """
    A :class:`SymbolLookup` that trivially throws for all of its functions.

    This can be used where a :class:`SymbolLookup` instance is useful but an implementation is not
    required.

    All methods are implemented such that if the provided ref has a package ID,
    :class:`PackageNotFoundError` is thrown; otherwise, :class:`NameNotFoundError` is thrown.
    """

    __slots__ = ()

    def archives(self) -> Collection[Archive]:
        return frozenset()

    def package_ids(self) -> AbstractSet[PackageRef]:
        return frozenset()

    def search(self, ref: str | TypeConName, /, *, throw_if_missing: bool = True) -> LookupResult:
        raise empty_lookup_impl(ref)


class PackageLookup(SymbolLookup):
    """
    Caching structure to make lookups on type names within a :class:`Package` faster.
    """

    def __init__(self, archive: Archive):
        self.archive = archive

        # mappings of "naked names" (no package ID or package name) to items
        data_types = dict[str, LookupMappingItem[TypeConName, DefDataType]]()
        values = dict[str, LookupMappingItem[ValName, DefValue]]()
        templates = dict[str, LookupMappingItem[TypeConName, DefTemplate]]()
        interfaces = dict[str, LookupMappingItem[TypeConName, DefInterface]]()
        package_name = (
            PackageRef(f"#{self.archive.package.metadata.name}")
            if self.archive.package.metadata is not None
            else None
        )

        for module in archive.package.modules:
            module_id_ref = ModuleRef(archive.hash, module.name)
            module_name_ref = (
                ModuleRef(package_name, module.name) if package_name is not None else None
            )

            for dt in module.data_types:
                dt_id_ref = TypeConName(module_id_ref, dt.name.segments)
                dt_name_ref = (
                    TypeConName(module_name_ref, dt.name.segments)
                    if module_name_ref is not None
                    else None
                )
                data_types[f"{module.name}:{dt.name}"] = LookupMappingItem(
                    dt_id_ref, dt_name_ref, dt
                )

            for value in module.values:
                value_id_ref = ValName(module_id_ref, value.name_with_type.name)
                value_name_ref = (
                    ValName(module_name_ref, value.name_with_type.name)
                    if module_name_ref is not None
                    else None
                )
                values[f"{module.name}:{value.name_with_type.name}"] = LookupMappingItem(
                    value_id_ref, value_name_ref, value
                )

            for tmpl in module.templates:
                tmpl_id_ref = TypeConName(module_id_ref, tmpl.tycon.segments)
                tmpl_name_ref = (
                    TypeConName(module_name_ref, tmpl.tycon.segments)
                    if module_name_ref is not None
                    else None
                )
                templates[f"{module.name}:{tmpl.tycon}"] = LookupMappingItem(
                    tmpl_id_ref, tmpl_name_ref, tmpl
                )

            for iface in module.interfaces:
                iface_id_ref = TypeConName(module_id_ref, iface.name.segments)
                iface_name_ref = (
                    TypeConName(module_name_ref, iface.name.segments)
                    if module_name_ref is not None
                    else None
                )
                interfaces[f"{module.name}:{iface.name}"] = LookupMappingItem(
                    iface_id_ref, iface_name_ref, iface
                )

        self._package_name = (
            PackageRef(f"#{self.archive.package.metadata.name}")
            if self.archive.package.metadata is not None
            else None
        )
        self._data_types = MappingProxyType[str, LookupMappingItem[TypeConName, DefDataType]](
            data_types
        )
        self._values = MappingProxyType[str, LookupMappingItem[ValName, DefValue]](values)
        self._templates = MappingProxyType[str, LookupMappingItem[TypeConName, DefTemplate]](
            templates
        )
        self._interfaces = MappingProxyType[str, LookupMappingItem[TypeConName, DefInterface]](
            interfaces
        )

    def archives(self) -> Collection[Archive]:
        return [self.archive]

    def package_ids(self) -> AbstractSet[PackageRef]:
        return frozenset([self.archive.hash])

    @property
    def scu_package_name(self) -> Optional[PackageRef]:
        """
        Return the Smart Contract Upgradable (SCU) name of this package, with the preceding hash tag.
        """
        return self._package_name

    def search(self, ref: str | TypeConName, /, *, throw_if_missing: bool = True) -> LookupResult:
        """
        Search for symbols that match the specified string.

        :param ref:
            The string or :class:`TypeConName` to search for.
        :param throw_if_missing:
            Throw a :class:`NameNotFoundError` if no objects are returned; otherwise,
            return an empty object. The default behavior is to throw.
        :return:
            A :class:`LookupResult` that indicates the found objects.
        """
        pkg, name = validate_template(ref)
        if pkg == self.archive.hash or pkg == self.scu_package_name or pkg == STAR:
            if name == "*":
                # unspecified name, so return everything from everywhere
                return LookupResult(
                    ref,
                    data_types=tuple(self._data_types.values()),
                    values=tuple(self._values.values()),
                    templates=tuple(self._templates.values()),
                    interfaces=tuple(self._interfaces.values()),
                )
            else:
                data_type = self._data_types.get(name)
                value = self._values.get(name)
                template = self._templates.get(name)
                interface = self._interfaces.get(name)
                return LookupResult(
                    ref,
                    data_types=(data_type,) if data_type is not None else (),
                    values=(value,) if value is not None else (),
                    templates=(template,) if template is not None else (),
                    interfaces=(interface,) if interface is not None else (),
                )

        raise NameNotFoundError(ref)


class MultiPackageLookup(SymbolLookup):
    """
    Combines lookups across multiple archives.

    This class is thread-safe. When calling :meth:`add_archive` and any of the other read-only
    methods concurrently, read-only methods will NOT block; they will return the previous state
    of the lookup.

    Packages can only be added; they cannot be removed once added.
    """

    _cache_by_pkg_id: Mapping[PackageRef, PackageLookup]
    _cache_by_name: Mapping[PackageRef, Sequence[PackageLookup]]

    def __init__(self, archives: Optional[Collection[Archive]] = None):
        self._lock = threading.Lock()
        self._cache_by_pkg_id = MappingProxyType({})
        self._cache_by_name = MappingProxyType({})
        if archives is not None:
            self.add_archive(*archives)

    def archives(self) -> Collection[Archive]:
        """
        Return the list of known archives.
        """
        return [lookup.archive for lookup in self._cache_by_pkg_id.values()]

    def add_archive(self, *a: Archive) -> None:
        """
        Add one or more :class:`Archive` instances to this lookup.

        This method is thread-safe, but note that :class:`MultiPackageLookup` allows dirty reads for
        performance reasons.

        :param a: One or more :class:`Archive` instances to add.
        """
        new_lookups_by_id = {ar.hash: PackageLookup(ar) for ar in a}
        with self._lock:
            # replace the old cache with a new one, incorporating values from both the existing
            # cache and the new lookups that came in. When there is a key conflict between the two
            # APIs, always prefer the existing cache to provide stability to callers.
            cache_by_id = {**new_lookups_by_id, **self._cache_by_pkg_id}

            # (re)build the by-name package cache for smart contract upgrade (SCU) support;
            # we also allow template lookups by package name, and will prefer the most recent
            # version
            lookups_by_name = defaultdict[PackageRef, list[PackageLookup]](list)
            for package_lookup in cache_by_id.values():
                scu_name = package_lookup.scu_package_name
                if scu_name is not None:
                    lookups_by_name[scu_name].append(package_lookup)

            cache_by_name = {
                scu_pkg_ref: sorted(package_lookups, key=get_version_tuple)
                for scu_pkg_ref, package_lookups in lookups_by_name.items()
            }

            self._cache_by_pkg_id = cache_by_id
            self._cache_by_name = cache_by_name
            LOG.debug(
                "Updated package cache; now contains %d packages.", len(self._cache_by_pkg_id)
            )

    def package_ids(self) -> AbstractSet[PackageRef]:
        """
        Return the package IDs of packages stored in this lookup.

        Because the data is local and in memory, the timeout parameter is ignored.
        """
        return set(self._cache_by_pkg_id)

    def package(self, ref: PackageRef) -> Package:
        lookups = list(self._lookups(ref))
        if len(lookups) == 1:
            return lookups[0].archive.package

        # TODO: More descriptive error message here
        raise PackageNotFoundError(ref)

    def search(self, ref: str | TypeConName, /, *, throw_if_missing: bool = True) -> LookupResult:
        pkg, name = validate_template(ref)
        result = LookupResult(ref)
        for lookup in self._lookups(pkg, throw_if_missing=throw_if_missing):
            result += lookup.search(ref, throw_if_missing=False)

        if throw_if_missing and not result:
            raise NameNotFoundError(ref)

        return result

    def _lookups(
        self, ref: PackageRef, /, throw_if_missing: bool = True
    ) -> Iterable[PackageLookup]:
        """
        Return the individual :class:`PackageLookup` objects that should be consulted based on the
        :class:`PackageRef`.

        :param ref:
            A :class:`PackageRef` to look for.
        :return:
            A collection of :class:`PackageLookup` objects that match the :class:`PackageRef`. This
            collection is never empty.
        :raises PackageNotFoundError:
            if the :class:`PackageRef` points to a package that is not present in this lookup.
        """
        if ref == STAR:
            # unspecified package ID, so return all possible package lookups
            return self._cache_by_pkg_id.values()

        elif ref.startswith("#"):
            # SCU-style template reference; find the most up-to-date package for this package name
            lookups = self._cache_by_name.get(ref)
            if lookups is not None:
                return lookups

        else:
            lookup = self._cache_by_pkg_id.get(ref)
            if lookup is not None:
                return (lookup,)

        if throw_if_missing:
            raise PackageNotFoundError(ref)
        else:
            return ()


class PackageExceptionTracker:
    """
    A context manager that gracefully recovers from errors related to missing packages that are
    retryable.
    """

    def __init__(self) -> None:
        self._seen_types = set[str]()
        self._seen_packages = set[PackageRef]()
        self._pkg_refs = list[PackageRef]()
        self.done = False

    def __enter__(self):
        return self

    def __exit__(self, exc_type, exc_val, exc_tb):
        if isinstance(exc_val, PackageNotFoundError):
            # every time we fail serialization due to a missing package or type,
            # try to resolve it; remember what we tried, because if we fail again
            # for the same reason it is likely fatal
            if exc_val.ref in self._seen_packages:
                # we already looked for this package and couldn't find it; this will
                # never succeed, so we can't suppress this error
                return None

            self._seen_packages.add(exc_val.ref)

            # the caller should try to load the offending package, and then retry the operation
            self._pkg_refs.append(exc_val.ref)
            return True

        elif isinstance(exc_val, NameNotFoundError):
            if exc_val.ref in self._seen_types:
                # we already looked for this type and couldn't find it; this will
                # never succeed
                LOG.verbose(
                    "Failed to find name %s in all known packages, even after fetching the latest.",
                    exc_val.ref,
                )
                raise

            with warnings.catch_warnings():
                warnings.simplefilter("ignore", DeprecationWarning)
                pkg_id, name = validate_template(exc_val.ref)
            if pkg_id == "*":
                # we don't know what package contains this type, so we have no
                # choice but to look in all known packages
                LOG.verbose(
                    "Failed to find name %s in all known packages, so loading ALL packages...",
                    name,
                )
                self._seen_types.add(exc_val.ref)

                # the caller should load all packages, and then retry the operation
                self._pkg_refs.append(STAR)
                return True
            else:
                # we know what package this type comes from, but it did not contain
                # the required type
                LOG.warning("Found package %s, but it did not include type %s", pkg_id, name)
                return None

    def pop_package(self) -> Optional[PackageRef]:
        """
        Return a :class:`PackageRef` that should be fetched before an operation is retried, or
        ``None`` if there is no such operation.
        """
        return self._pkg_refs.pop() if self._pkg_refs else None


def find_choice(template: DefTemplate, name: str) -> TemplateChoice:
    """
    Find a choice in a :class:`DefTemplate`. If the choice could not be found,
    :class:`NameNotFoundError` is raised.
    """
    for choice in template.choices:
        if choice.name == name:
            return choice

    raise NameNotFoundError(f"choice {name}")


def get_version_tuple(lookup: PackageLookup) -> tuple[int, ...]:
    md = lookup.archive.package.metadata
    if md is not None:
        return tuple([int(s) for s in md.version.split(".")])
    else:
        return ()



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

T = TypeVar("T", bound="IdentityProviderConfig")


@_attrs_define
class IdentityProviderConfig:
    """
    Attributes:
        identity_provider_id (str): The identity provider identifier
            Must be a valid LedgerString (as describe in ``value.proto``).
            Required
        is_deactivated (bool): When set, the callers using JWT tokens issued by this identity provider are denied all
            access
            to the Ledger API.
            Optional,
            Modifiable
        issuer (str): Specifies the issuer of the JWT token.
            The issuer value is a case sensitive URL using the https scheme that contains scheme, host,
            and optionally, port number and path components and no query or fragment components.
            Required
            Modifiable
        jwks_url (str): The JWKS (JSON Web Key Set) URL.
            The Ledger API uses JWKs (JSON Web Keys) from the provided URL to verify that the JWT has been
            signed with the loaded JWK. Only RS256 (RSA Signature with SHA-256) signing algorithm is supported.
            Required
            Modifiable
        audience (str): Specifies the audience of the JWT token.
            When set, the callers using JWT tokens issued by this identity provider are allowed to get an access
            only if the "aud" claim includes the string specified here
            Optional,
            Modifiable
    """

    identity_provider_id: str
    is_deactivated: bool
    issuer: str
    jwks_url: str
    audience: str
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        identity_provider_id = self.identity_provider_id

        is_deactivated = self.is_deactivated

        issuer = self.issuer

        jwks_url = self.jwks_url

        audience = self.audience

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "identityProviderId": identity_provider_id,
                "isDeactivated": is_deactivated,
                "issuer": issuer,
                "jwksUrl": jwks_url,
                "audience": audience,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        identity_provider_id = d.pop("identityProviderId")

        is_deactivated = d.pop("isDeactivated")

        issuer = d.pop("issuer")

        jwks_url = d.pop("jwksUrl")

        audience = d.pop("audience")

        identity_provider_config = cls(
            identity_provider_id=identity_provider_id,
            is_deactivated=is_deactivated,
            issuer=issuer,
            jwks_url=jwks_url,
            audience=audience,
        )

        identity_provider_config.additional_properties = d
        return identity_provider_config

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/daml/ledger/api/v2/transaction_filter.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/daml/ledger/api/v2/transaction_filter.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import value_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v2_dot_value__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/com/daml/ledger/api/v2/transaction_filter.proto\x12\x16\x63om.daml.ledger.api.v2\x1a\"com/daml/ledger/api/v2/value.proto\"S\n\x07\x46ilters\x12H\n\ncumulative\x18\x01 \x03(\x0b\x32(.com.daml.ledger.api.v2.CumulativeFilterR\ncumulative\"\xa3\x02\n\x10\x43umulativeFilter\x12Q\n\x0fwildcard_filter\x18\x01 \x01(\x0b\x32&.com.daml.ledger.api.v2.WildcardFilterH\x00R\x0ewildcardFilter\x12T\n\x10interface_filter\x18\x02 \x01(\x0b\x32\'.com.daml.ledger.api.v2.InterfaceFilterH\x00R\x0finterfaceFilter\x12Q\n\x0ftemplate_filter\x18\x03 \x01(\x0b\x32&.com.daml.ledger.api.v2.TemplateFilterH\x00R\x0etemplateFilterB\x13\n\x11identifier_filter\"M\n\x0eWildcardFilter\x12;\n\x1ainclude_created_event_blob\x18\x01 \x01(\x08R\x17includeCreatedEventBlob\"\xcb\x01\n\x0fInterfaceFilter\x12\x45\n\x0cinterface_id\x18\x01 \x01(\x0b\x32\".com.daml.ledger.api.v2.IdentifierR\x0binterfaceId\x12\x34\n\x16include_interface_view\x18\x02 \x01(\x08R\x14includeInterfaceView\x12;\n\x1ainclude_created_event_blob\x18\x03 \x01(\x08R\x17includeCreatedEventBlob\"\x92\x01\n\x0eTemplateFilter\x12\x43\n\x0btemplate_id\x18\x01 \x01(\x0b\x32\".com.daml.ledger.api.v2.IdentifierR\ntemplateId\x12;\n\x1ainclude_created_event_blob\x18\x02 \x01(\x08R\x17includeCreatedEventBlob\"\xc2\x02\n\x0b\x45ventFormat\x12\x61\n\x10\x66ilters_by_party\x18\x01 \x03(\x0b\x32\x37.com.daml.ledger.api.v2.EventFormat.FiltersByPartyEntryR\x0e\x66iltersByParty\x12R\n\x15\x66ilters_for_any_party\x18\x02 \x01(\x0b\x32\x1f.com.daml.ledger.api.v2.FiltersR\x12\x66iltersForAnyParty\x12\x18\n\x07verbose\x18\x03 \x01(\x08R\x07verbose\x1a\x62\n\x13\x46iltersByPartyEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x35\n\x05value\x18\x02 \x01(\x0b\x32\x1f.com.daml.ledger.api.v2.FiltersR\x05value:\x02\x38\x01\"\xb2\x01\n\x11TransactionFormat\x12\x46\n\x0c\x65vent_format\x18\x01 \x01(\x0b\x32#.com.daml.ledger.api.v2.EventFormatR\x0b\x65ventFormat\x12U\n\x11transaction_shape\x18\x02 \x01(\x0e\x32(.com.daml.ledger.api.v2.TransactionShapeR\x10transactionShape\"\xaa\x01\n\x0eTopologyFormat\x12\x97\x01\n(include_participant_authorization_events\x18\x01 \x01(\x0b\x32>.com.daml.ledger.api.v2.ParticipantAuthorizationTopologyFormatR%includeParticipantAuthorizationEvents\"B\n&ParticipantAuthorizationTopologyFormat\x12\x18\n\x07parties\x18\x01 \x03(\tR\x07parties\"\xa6\x02\n\x0cUpdateFormat\x12\\\n\x14include_transactions\x18\x01 \x01(\x0b\x32).com.daml.ledger.api.v2.TransactionFormatR\x13includeTransactions\x12X\n\x15include_reassignments\x18\x02 \x01(\x0b\x32#.com.daml.ledger.api.v2.EventFormatR\x14includeReassignments\x12^\n\x17include_topology_events\x18\x03 \x01(\x0b\x32&.com.daml.ledger.api.v2.TopologyFormatR\x15includeTopologyEvents*|\n\x10TransactionShape\x12!\n\x1dTRANSACTION_SHAPE_UNSPECIFIED\x10\x00\x12\x1f\n\x1bTRANSACTION_SHAPE_ACS_DELTA\x10\x01\x12$\n TRANSACTION_SHAPE_LEDGER_EFFECTS\x10\x02\x42\x95\x01\n\x16\x63om.daml.ledger.api.v2B\x1bTransactionFilterOuterClassZEgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v2\xaa\x02\x16\x43om.Daml.Ledger.Api.V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.daml.ledger.api.v2.transaction_filter_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.daml.ledger.api.v2B\033TransactionFilterOuterClassZEgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v2\252\002\026Com.Daml.Ledger.Api.V2'
  _globals['_EVENTFORMAT_FILTERSBYPARTYENTRY']._loaded_options = None
  _globals['_EVENTFORMAT_FILTERSBYPARTYENTRY']._serialized_options = b'8\001'
  _globals['_TRANSACTIONSHAPE']._serialized_start=1968
  _globals['_TRANSACTIONSHAPE']._serialized_end=2092
  _globals['_FILTERS']._serialized_start=111
  _globals['_FILTERS']._serialized_end=194
  _globals['_CUMULATIVEFILTER']._serialized_start=197
  _globals['_CUMULATIVEFILTER']._serialized_end=488
  _globals['_WILDCARDFILTER']._serialized_start=490
  _globals['_WILDCARDFILTER']._serialized_end=567
  _globals['_INTERFACEFILTER']._serialized_start=570
  _globals['_INTERFACEFILTER']._serialized_end=773
  _globals['_TEMPLATEFILTER']._serialized_start=776
  _globals['_TEMPLATEFILTER']._serialized_end=922
  _globals['_EVENTFORMAT']._serialized_start=925
  _globals['_EVENTFORMAT']._serialized_end=1247
  _globals['_EVENTFORMAT_FILTERSBYPARTYENTRY']._serialized_start=1149
  _globals['_EVENTFORMAT_FILTERSBYPARTYENTRY']._serialized_end=1247
  _globals['_TRANSACTIONFORMAT']._serialized_start=1250
  _globals['_TRANSACTIONFORMAT']._serialized_end=1428
  _globals['_TOPOLOGYFORMAT']._serialized_start=1431
  _globals['_TOPOLOGYFORMAT']._serialized_end=1601
  _globals['_PARTICIPANTAUTHORIZATIONTOPOLOGYFORMAT']._serialized_start=1603
  _globals['_PARTICIPANTAUTHORIZATIONTOPOLOGYFORMAT']._serialized_end=1669
  _globals['_UPDATEFORMAT']._serialized_start=1672
  _globals['_UPDATEFORMAT']._serialized_end=1966
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

import builtins as _builtins, typing as _typing

import grpc as _grpc
from grpc import aio as _grpc_aio

from .state_service_pb2 import GetActiveContractsRequest, GetActiveContractsResponse, GetConnectedSynchronizersRequest, GetConnectedSynchronizersResponse, GetLatestPrunedOffsetsRequest, GetLatestPrunedOffsetsResponse, GetLedgerEndRequest, GetLedgerEndResponse

__all__ = [
    "StateServiceStub",
]


# noinspection PyPep8Naming,DuplicatedCode
class StateServiceStub:
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc.Channel) -> _StateServiceBlockingStub: ...  # type: ignore
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc_aio.Channel) -> _StateServiceAsyncStub: ...  # type: ignore
    def GetActiveContracts(self, __1: GetActiveContractsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc.CallIterator[GetActiveContractsResponse] | _grpc_aio.UnaryStreamCall[_typing.Any, GetActiveContractsResponse]: ...
    def GetConnectedSynchronizers(self, __1: GetConnectedSynchronizersRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> GetConnectedSynchronizersResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, GetConnectedSynchronizersResponse]: ...
    def GetLedgerEnd(self, __1: GetLedgerEndRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> GetLedgerEndResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, GetLedgerEndResponse]: ...
    def GetLatestPrunedOffsets(self, __1: GetLatestPrunedOffsetsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> GetLatestPrunedOffsetsResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, GetLatestPrunedOffsetsResponse]: ...

# noinspection PyPep8Naming,DuplicatedCode
class _StateServiceBlockingStub(StateServiceStub):
    def GetActiveContracts(self, __1: GetActiveContractsRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc.CallIterator[GetActiveContractsResponse]: ...
    def GetConnectedSynchronizers(self, __1: GetConnectedSynchronizersRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> GetConnectedSynchronizersResponse: ...
    def GetLedgerEnd(self, __1: GetLedgerEndRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> GetLedgerEndResponse: ...
    def GetLatestPrunedOffsets(self, __1: GetLatestPrunedOffsetsRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> GetLatestPrunedOffsetsResponse: ...

# noinspection PyPep8Naming,DuplicatedCode
class _StateServiceAsyncStub(StateServiceStub):
    def GetActiveContracts(self, __1: GetActiveContractsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryStreamCall[_typing.Any, GetActiveContractsResponse]: ...  # type: ignore
    def GetConnectedSynchronizers(self, __1: GetConnectedSynchronizersRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, GetConnectedSynchronizersResponse]: ...  # type: ignore
    def GetLedgerEnd(self, __1: GetLedgerEndRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, GetLedgerEndResponse]: ...  # type: ignore
    def GetLatestPrunedOffsets(self, __1: GetLatestPrunedOffsetsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, GetLatestPrunedOffsetsResponse]: ...  # type: ignore



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="PackageMetadataFilter")


@_attrs_define
class PackageMetadataFilter:
    """Filter the VettedPackages by package metadata.

    A PackageMetadataFilter without package_ids and without package_name_prefixes
    matches any vetted package.

    Non-empty fields specify candidate values of which at least one must match.
    If both fields are set, then a candidate is returned if it matches one of the fields.

        Attributes:
            package_ids (list[str] | Unset): If this list is non-empty, any vetted package with a package ID in this
                list will match the filter.
            package_name_prefixes (list[str] | Unset): If this list is non-empty, any vetted package with a name matching at
                least
                one prefix in this list will match the filter.
    """

    package_ids: list[str] | Unset = UNSET
    package_name_prefixes: list[str] | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        package_ids: list[str] | Unset = UNSET
        if not isinstance(self.package_ids, Unset):
            package_ids = self.package_ids

        package_name_prefixes: list[str] | Unset = UNSET
        if not isinstance(self.package_name_prefixes, Unset):
            package_name_prefixes = self.package_name_prefixes

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if package_ids is not UNSET:
            field_dict["packageIds"] = package_ids
        if package_name_prefixes is not UNSET:
            field_dict["packageNamePrefixes"] = package_name_prefixes

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        package_ids = cast(list[str], d.pop("packageIds", UNSET))

        package_name_prefixes = cast(list[str], d.pop("packageNamePrefixes", UNSET))

        package_metadata_filter = cls(
            package_ids=package_ids,
            package_name_prefixes=package_name_prefixes,
        )

        package_metadata_filter.additional_properties = d
        return package_metadata_filter

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

import builtins as _builtins, typing as _typing

import grpc as _grpc
from grpc import aio as _grpc_aio

from .inspection_service_pb2 import CountInFlight, LookupContractDomain, LookupOffsetByIndex, LookupOffsetByTime, LookupTransactionDomain

__all__ = [
    "InspectionServiceStub",
]


# noinspection PyPep8Naming,DuplicatedCode
class InspectionServiceStub:
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc.Channel) -> _InspectionServiceBlockingStub: ...  # type: ignore
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc_aio.Channel) -> _InspectionServiceAsyncStub: ...  # type: ignore
    def LookupContractDomain(self, __1: LookupContractDomain.Request, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> LookupContractDomain.Response | _grpc_aio.UnaryUnaryCall[_typing.Any, LookupContractDomain.Response]: ...
    def LookupTransactionDomain(self, __1: LookupTransactionDomain.Request, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> LookupTransactionDomain.Response | _grpc_aio.UnaryUnaryCall[_typing.Any, LookupTransactionDomain.Response]: ...
    def LookupOffsetByTime(self, __1: LookupOffsetByTime.Request, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> LookupOffsetByTime.Response | _grpc_aio.UnaryUnaryCall[_typing.Any, LookupOffsetByTime.Response]: ...
    def LookupOffsetByIndex(self, __1: LookupOffsetByIndex.Request, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> LookupOffsetByIndex.Response | _grpc_aio.UnaryUnaryCall[_typing.Any, LookupOffsetByIndex.Response]: ...
    def CountInFlight(self, __1: CountInFlight.Request, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> CountInFlight.Response | _grpc_aio.UnaryUnaryCall[_typing.Any, CountInFlight.Response]: ...

# noinspection PyPep8Naming,DuplicatedCode
class _InspectionServiceBlockingStub(InspectionServiceStub):
    def LookupContractDomain(self, __1: LookupContractDomain.Request, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> LookupContractDomain.Response: ...
    def LookupTransactionDomain(self, __1: LookupTransactionDomain.Request, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> LookupTransactionDomain.Response: ...
    def LookupOffsetByTime(self, __1: LookupOffsetByTime.Request, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> LookupOffsetByTime.Response: ...
    def LookupOffsetByIndex(self, __1: LookupOffsetByIndex.Request, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> LookupOffsetByIndex.Response: ...
    def CountInFlight(self, __1: CountInFlight.Request, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> CountInFlight.Response: ...

# noinspection PyPep8Naming,DuplicatedCode
class _InspectionServiceAsyncStub(InspectionServiceStub):
    def LookupContractDomain(self, __1: LookupContractDomain.Request, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, LookupContractDomain.Response]: ...  # type: ignore
    def LookupTransactionDomain(self, __1: LookupTransactionDomain.Request, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, LookupTransactionDomain.Response]: ...  # type: ignore
    def LookupOffsetByTime(self, __1: LookupOffsetByTime.Request, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, LookupOffsetByTime.Response]: ...  # type: ignore
    def LookupOffsetByIndex(self, __1: LookupOffsetByIndex.Request, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, LookupOffsetByIndex.Response]: ...  # type: ignore
    def CountInFlight(self, __1: CountInFlight.Request, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, CountInFlight.Response]: ...  # type: ignore



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from __future__ import annotations

from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.command_type_0 import CommandType0
    from ..models.command_type_1 import CommandType1
    from ..models.command_type_2 import CommandType2
    from ..models.command_type_3 import CommandType3
    from ..models.deduplication_period_type_0 import DeduplicationPeriodType0
    from ..models.deduplication_period_type_1 import DeduplicationPeriodType1
    from ..models.deduplication_period_type_2 import DeduplicationPeriodType2
    from ..models.disclosed_contract import DisclosedContract
    from ..models.duration import Duration
    from ..models.prefetch_contract_key import PrefetchContractKey


T = TypeVar("T", bound="JsCommands")


@_attrs_define
class JsCommands:
    """A composite command that groups multiple commands together.

    Attributes:
        command_id (str): Uniquely identifies the command.
            The triple (user_id, act_as, command_id) constitutes the change ID for the intended ledger change,
            where act_as is interpreted as a set of party names.
            The change ID can be used for matching the intended ledger changes with all their completions.
            Must be a valid LedgerString (as described in ``value.proto``).
            Required
        commands (list[CommandType0 | CommandType1 | CommandType2 | CommandType3] | Unset): Individual elements of this
            atomic command. Must be non-empty.
            Required
        act_as (list[str] | Unset): Set of parties on whose behalf the command should be executed.
            If ledger API authorization is enabled, then the authorization metadata must authorize the sender of the request
            to act on behalf of each of the given parties.
            Each element must be a valid PartyIdString (as described in ``value.proto``).
            Required, must be non-empty.
        user_id (str | Unset): Uniquely identifies the participant user that issued the command.
            Must be a valid UserIdString (as described in ``value.proto``).
            Required unless authentication is used with a user token.
            In that case, the token's user-id will be used for the request's user_id.
        read_as (list[str] | Unset): Set of parties on whose behalf (in addition to all parties listed in ``act_as``)
            contracts can be retrieved.
            This affects Daml operations such as ``fetch``, ``fetchByKey``, ``lookupByKey``, ``exercise``, and
            ``exerciseByKey``.
            Note: A participant node of a Daml network can host multiple parties. Each contract present on the participant
            node is only visible to a subset of these parties. A command can only use contracts that are visible to at least
            one of the parties in ``act_as`` or ``read_as``. This visibility check is independent from the Daml
            authorization
            rules for fetch operations.
            If ledger API authorization is enabled, then the authorization metadata must authorize the sender of the request
            to read contract data on behalf of each of the given parties.
            Optional
        workflow_id (str | Unset): Identifier of the on-ledger workflow that this command is a part of.
            Must be a valid LedgerString (as described in ``value.proto``).
            Optional
        deduplication_period (DeduplicationPeriodType0 | DeduplicationPeriodType1 | DeduplicationPeriodType2 | Unset):
            Specifies the deduplication period for the change ID.
            If omitted, the participant will assume the configured maximum deduplication time.
        min_ledger_time_abs (str | Unset): Lower bound for the ledger time assigned to the resulting transaction.
            Note: The ledger time of a transaction is assigned as part of command interpretation.
            Use this property if you expect that command interpretation will take a considerate amount of time, such that by
            the time the resulting transaction is sequenced, its assigned ledger time is not valid anymore.
            Must not be set at the same time as min_ledger_time_rel.
            Optional
        min_ledger_time_rel (Duration | Unset):
        submission_id (str | Unset): A unique identifier to distinguish completions for different submissions with the
            same change ID.
            Typically a random UUID. Applications are expected to use a different UUID for each retry of a submission
            with the same change ID.
            Must be a valid LedgerString (as described in ``value.proto``).

            If omitted, the participant or the committer may set a value of their choice.
            Optional
        disclosed_contracts (list[DisclosedContract] | Unset): Additional contracts used to resolve contract & contract
            key lookups.
            Optional
        synchronizer_id (str | Unset): Must be a valid synchronizer id
            Optional
        package_id_selection_preference (list[str] | Unset): The package-id selection preference of the client for
            resolving
            package names and interface instances in command submission and interpretation
        prefetch_contract_keys (list[PrefetchContractKey] | Unset): Fetches the contract keys into the caches to speed
            up the command processing.
            Should only contain contract keys that are expected to be resolved during interpretation of the commands.
            Keys of disclosed contracts do not need prefetching.

            Optional
    """

    command_id: str
    commands: (
        list[CommandType0 | CommandType1 | CommandType2 | CommandType3] | Unset
    ) = UNSET
    act_as: list[str] | Unset = UNSET
    user_id: str | Unset = UNSET
    read_as: list[str] | Unset = UNSET
    workflow_id: str | Unset = UNSET
    deduplication_period: (
        DeduplicationPeriodType0
        | DeduplicationPeriodType1
        | DeduplicationPeriodType2
        | Unset
    ) = UNSET
    min_ledger_time_abs: str | Unset = UNSET
    min_ledger_time_rel: Duration | Unset = UNSET
    submission_id: str | Unset = UNSET
    disclosed_contracts: list[DisclosedContract] | Unset = UNSET
    synchronizer_id: str | Unset = UNSET
    package_id_selection_preference: list[str] | Unset = UNSET
    prefetch_contract_keys: list[PrefetchContractKey] | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        from ..models.command_type_0 import CommandType0
        from ..models.command_type_1 import CommandType1
        from ..models.command_type_2 import CommandType2
        from ..models.deduplication_period_type_0 import DeduplicationPeriodType0
        from ..models.deduplication_period_type_1 import DeduplicationPeriodType1

        command_id = self.command_id

        commands: list[dict[str, Any]] | Unset = UNSET
        if not isinstance(self.commands, Unset):
            commands = []
            for commands_item_data in self.commands:
                commands_item: dict[str, Any]
                if isinstance(commands_item_data, CommandType0):
                    commands_item = commands_item_data.to_dict()
                elif isinstance(commands_item_data, CommandType1):
                    commands_item = commands_item_data.to_dict()
                elif isinstance(commands_item_data, CommandType2):
                    commands_item = commands_item_data.to_dict()
                else:
                    commands_item = commands_item_data.to_dict()

                commands.append(commands_item)

        act_as: list[str] | Unset = UNSET
        if not isinstance(self.act_as, Unset):
            act_as = self.act_as

        user_id = self.user_id

        read_as: list[str] | Unset = UNSET
        if not isinstance(self.read_as, Unset):
            read_as = self.read_as

        workflow_id = self.workflow_id

        deduplication_period: dict[str, Any] | Unset
        if isinstance(self.deduplication_period, Unset):
            deduplication_period = UNSET
        elif isinstance(self.deduplication_period, DeduplicationPeriodType0):
            deduplication_period = self.deduplication_period.to_dict()
        elif isinstance(self.deduplication_period, DeduplicationPeriodType1):
            deduplication_period = self.deduplication_period.to_dict()
        else:
            deduplication_period = self.deduplication_period.to_dict()

        min_ledger_time_abs = self.min_ledger_time_abs

        min_ledger_time_rel: dict[str, Any] | Unset = UNSET
        if not isinstance(self.min_ledger_time_rel, Unset):
            min_ledger_time_rel = self.min_ledger_time_rel.to_dict()

        submission_id = self.submission_id

        disclosed_contracts: list[dict[str, Any]] | Unset = UNSET
        if not isinstance(self.disclosed_contracts, Unset):
            disclosed_contracts = []
            for disclosed_contracts_item_data in self.disclosed_contracts:
                disclosed_contracts_item = disclosed_contracts_item_data.to_dict()
                disclosed_contracts.append(disclosed_contracts_item)

        synchronizer_id = self.synchronizer_id

        package_id_selection_preference: list[str] | Unset = UNSET
        if not isinstance(self.package_id_selection_preference, Unset):
            package_id_selection_preference = self.package_id_selection_preference

        prefetch_contract_keys: list[dict[str, Any]] | Unset = UNSET
        if not isinstance(self.prefetch_contract_keys, Unset):
            prefetch_contract_keys = []
            for prefetch_contract_keys_item_data in self.prefetch_contract_keys:
                prefetch_contract_keys_item = prefetch_contract_keys_item_data.to_dict()
                prefetch_contract_keys.append(prefetch_contract_keys_item)

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "commandId": command_id,
            }
        )
        if commands is not UNSET:
            field_dict["commands"] = commands
        if act_as is not UNSET:
            field_dict["actAs"] = act_as
        if user_id is not UNSET:
            field_dict["userId"] = user_id
        if read_as is not UNSET:
            field_dict["readAs"] = read_as
        if workflow_id is not UNSET:
            field_dict["workflowId"] = workflow_id
        if deduplication_period is not UNSET:
            field_dict["deduplicationPeriod"] = deduplication_period
        if min_ledger_time_abs is not UNSET:
            field_dict["minLedgerTimeAbs"] = min_ledger_time_abs
        if min_ledger_time_rel is not UNSET:
            field_dict["minLedgerTimeRel"] = min_ledger_time_rel
        if submission_id is not UNSET:
            field_dict["submissionId"] = submission_id
        if disclosed_contracts is not UNSET:
            field_dict["disclosedContracts"] = disclosed_contracts
        if synchronizer_id is not UNSET:
            field_dict["synchronizerId"] = synchronizer_id
        if package_id_selection_preference is not UNSET:
            field_dict["packageIdSelectionPreference"] = package_id_selection_preference
        if prefetch_contract_keys is not UNSET:
            field_dict["prefetchContractKeys"] = prefetch_contract_keys

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.command_type_0 import CommandType0
        from ..models.command_type_1 import CommandType1
        from ..models.command_type_2 import CommandType2
        from ..models.command_type_3 import CommandType3
        from ..models.deduplication_period_type_0 import DeduplicationPeriodType0
        from ..models.deduplication_period_type_1 import DeduplicationPeriodType1
        from ..models.deduplication_period_type_2 import DeduplicationPeriodType2
        from ..models.disclosed_contract import DisclosedContract
        from ..models.duration import Duration
        from ..models.prefetch_contract_key import PrefetchContractKey

        d = dict(src_dict)
        command_id = d.pop("commandId")

        _commands = d.pop("commands", UNSET)
        commands: (
            list[CommandType0 | CommandType1 | CommandType2 | CommandType3] | Unset
        ) = UNSET
        if _commands is not UNSET:
            commands = []
            for commands_item_data in _commands:

                def _parse_commands_item(
                    data: object,
                ) -> CommandType0 | CommandType1 | CommandType2 | CommandType3:
                    try:
                        if not isinstance(data, dict):
                            raise TypeError()
                        componentsschemas_command_type_0 = CommandType0.from_dict(data)

                        return componentsschemas_command_type_0
                    except (TypeError, ValueError, AttributeError, KeyError):
                        pass
                    try:
                        if not isinstance(data, dict):
                            raise TypeError()
                        componentsschemas_command_type_1 = CommandType1.from_dict(data)

                        return componentsschemas_command_type_1
                    except (TypeError, ValueError, AttributeError, KeyError):
                        pass
                    try:
                        if not isinstance(data, dict):
                            raise TypeError()
                        componentsschemas_command_type_2 = CommandType2.from_dict(data)

                        return componentsschemas_command_type_2
                    except (TypeError, ValueError, AttributeError, KeyError):
                        pass
                    if not isinstance(data, dict):
                        raise TypeError()
                    componentsschemas_command_type_3 = CommandType3.from_dict(data)

                    return componentsschemas_command_type_3

                commands_item = _parse_commands_item(commands_item_data)

                commands.append(commands_item)

        act_as = cast(list[str], d.pop("actAs", UNSET))

        user_id = d.pop("userId", UNSET)

        read_as = cast(list[str], d.pop("readAs", UNSET))

        workflow_id = d.pop("workflowId", UNSET)

        def _parse_deduplication_period(
            data: object,
        ) -> (
            DeduplicationPeriodType0
            | DeduplicationPeriodType1
            | DeduplicationPeriodType2
            | Unset
        ):
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                componentsschemas_deduplication_period_type_0 = (
                    DeduplicationPeriodType0.from_dict(data)
                )

                return componentsschemas_deduplication_period_type_0
            except (TypeError, ValueError, AttributeError, KeyError):
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                componentsschemas_deduplication_period_type_1 = (
                    DeduplicationPeriodType1.from_dict(data)
                )

                return componentsschemas_deduplication_period_type_1
            except (TypeError, ValueError, AttributeError, KeyError):
                pass
            if not isinstance(data, dict):
                raise TypeError()
            componentsschemas_deduplication_period_type_2 = (
                DeduplicationPeriodType2.from_dict(data)
            )

            return componentsschemas_deduplication_period_type_2

        deduplication_period = _parse_deduplication_period(
            d.pop("deduplicationPeriod", UNSET)
        )

        min_ledger_time_abs = d.pop("minLedgerTimeAbs", UNSET)

        _min_ledger_time_rel = d.pop("minLedgerTimeRel", UNSET)
        min_ledger_time_rel: Duration | Unset
        if isinstance(_min_ledger_time_rel, Unset):
            min_ledger_time_rel = UNSET
        else:
            min_ledger_time_rel = Duration.from_dict(_min_ledger_time_rel)

        submission_id = d.pop("submissionId", UNSET)

        _disclosed_contracts = d.pop("disclosedContracts", UNSET)
        disclosed_contracts: list[DisclosedContract] | Unset = UNSET
        if _disclosed_contracts is not UNSET:
            disclosed_contracts = []
            for disclosed_contracts_item_data in _disclosed_contracts:
                disclosed_contracts_item = DisclosedContract.from_dict(
                    disclosed_contracts_item_data
                )

                disclosed_contracts.append(disclosed_contracts_item)

        synchronizer_id = d.pop("synchronizerId", UNSET)

        package_id_selection_preference = cast(
            list[str], d.pop("packageIdSelectionPreference", UNSET)
        )

        _prefetch_contract_keys = d.pop("prefetchContractKeys", UNSET)
        prefetch_contract_keys: list[PrefetchContractKey] | Unset = UNSET
        if _prefetch_contract_keys is not UNSET:
            prefetch_contract_keys = []
            for prefetch_contract_keys_item_data in _prefetch_contract_keys:
                prefetch_contract_keys_item = PrefetchContractKey.from_dict(
                    prefetch_contract_keys_item_data
                )

                prefetch_contract_keys.append(prefetch_contract_keys_item)

        js_commands = cls(
            command_id=command_id,
            commands=commands,
            act_as=act_as,
            user_id=user_id,
            read_as=read_as,
            workflow_id=workflow_id,
            deduplication_period=deduplication_period,
            min_ledger_time_abs=min_ledger_time_abs,
            min_ledger_time_rel=min_ledger_time_rel,
            submission_id=submission_id,
            disclosed_contracts=disclosed_contracts,
            synchronizer_id=synchronizer_id,
            package_id_selection_preference=package_id_selection_preference,
            prefetch_contract_keys=prefetch_contract_keys,
        )

        js_commands.additional_properties = d
        return js_commands

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
